@@ -375,7 +375,7 @@ TTT
 				{	
 					my ( $result, $resfile, $retrdata_ref, $reporttitle, $themereport, $counttheme, $countreport, $retfile, $semaphorego1, $semaphorego2, $semaphorestop1, $semaphorestop2, $textpattern, $afterlines ) = @_;
 					#my ( $result, $resfile, $retrdata_ref, $reporttitle, $themereport, $counttheme, $countreport, $retfile, $semaphorego1, $semaphorego2, $semaphorestop1, $semaphorestop2, $textpattern, $afterlines, $adhoclines ) = @_;
-					print $tee " IN RETRIEVE ADHOC: \$sim: $sim, \$resfile: $resfile, \$result: $result, \$reporttitle: $reporttitle, \$themereport: $themereport, \$counttheme: $counttheme, \$countreport, $countreport, \$retfile : $retfile \n";
+					#print $tee " IN RETRIEVE ADHOC: \$sim: $sim, \$resfile: $resfile, \$result: $result, \$reporttitle: $reporttitle, \$themereport: $themereport, \$counttheme: $counttheme, \$countreport, $countreport, \$retfile : $retfile \n";
 					#print $tee "\%retrievedata: " . dump( %retrievedata ); 
 					my @retrdata = @$retrdata_ref; #say $tee "\@retrdata " . dump(@retrdata);
 					#my $insert = eval { $adhoclines }; say $tee "\$insert: $insert";
@@ -589,10 +589,10 @@ $printthis
 					if ( $tooltype eq "esp-r" )
 					{
 						my $counttheme = 0;
-						say $tee "INRETRIEVE \@{ \$retrievedata{\$counttool} } " . dump( @{ $retrievedata{$counttool} } );
+						#say $tee "INRETRIEVE \@{ \$retrievedata{\$counttool} } " . dump( @{ $retrievedata{$counttool} } );
 						foreach my $retrievedatum ( @{ $retrievedata{$counttool} } )
 						{	
-							say $tee "INRETRIEVE \$retrievedatum " . dump( $retrievedatum );
+							#say $tee "INRETRIEVE \$retrievedatum " . dump( $retrievedatum );
 							my $reportdata_ref_ref = $reportdata{$counttool}->[$counttheme]; #say $tee "\$reportdata_ref_ref " . dump($reportdata_ref_ref);
 							my @retrievedatarefs = @{$retrievedatum}; #say $tee "\@retrievedatarefs " . dump(@retrievedatarefs);
 							my $simtitle = $simtitles{$counttool}->[ $counttheme ][0]; #say $tee "\$simtitle " . dump($simtitle);
@@ -648,15 +648,15 @@ $printthis
 									{
 										
 										
-										my %datarep = %$item; say $tee "\%datarep" . dump(%datarep); 
-										my $reporttitle = $datarep{reporttitle}; say $tee "\$reporttitle! " . dump($reporttitle); ###DDD HERE
-										my $themereport = $datarep{themereport}; say $tee "\$themereport " . dump($themereport); 
-										my $semaphorego1 = $datarep{semaphorego1}; say $tee "\$semaphorego1 " . dump($semaphorego1); 
-										my $semaphorego2 = $datarep{semaphorego2}; say $tee "\$semaphorego2 " . dump($semaphorego2); 
-										my $semaphorestop1 = $datarep{semaphorestop1}; say $tee "\$semaphorestop1 " . dump($semaphorestop1); 
-										my $semaphorestop2 = $datarep{semaphorestop2}; say $tee "\$semaphorestop2 " . dump($semaphorestop2); 
-										my $textpattern = $datarep{textpattern}; say $tee "\$textpattern " . dump($textpattern); 
-										my $afterlines = $datarep{afterlines}; say $tee "\$afterlines " . dump($afterlines); 
+										my %datarep = %$item; #say $tee "\%datarep" . dump(%datarep); 
+										my $reporttitle = $datarep{reporttitle}; #say $tee "\$reporttitle! " . dump($reporttitle); ###DDD HERE
+										my $themereport = $datarep{themereport}; #say $tee "\$themereport " . dump($themereport); 
+										my $semaphorego1 = $datarep{semaphorego1}; #say $tee "\$semaphorego1 " . dump($semaphorego1); 
+										my $semaphorego2 = $datarep{semaphorego2}; #say $tee "\$semaphorego2 " . dump($semaphorego2); 
+										my $semaphorestop1 = $datarep{semaphorestop1}; #say $tee "\$semaphorestop1 " . dump($semaphorestop1); 
+										my $semaphorestop2 = $datarep{semaphorestop2}; #say $tee "\$semaphorestop2 " . dump($semaphorestop2); 
+										my $textpattern = $datarep{textpattern}; #say $tee "\$textpattern " . dump($textpattern); 
+										my $afterlines = $datarep{afterlines}; #say $tee "\$afterlines " . dump($afterlines); 
 										#my $adhoclines = $datarep{adhoclines}; say $tee "\$adhoclines " . dump($adhoclines); 
 										my $retfile = "$resfile-$reporttitle-$themereport.grt"; #say $tee "\$retfile " . dump($retfile); say TOFILE "\$retfile " . dump($retfile); say TOFILE "\$retfile " . dump($retfile);
 										
@@ -812,9 +812,9 @@ $printthis
 	close TOFILE;
 	close RETLIST;
 	close RETBLOCK;
-	say $tee "INEXIT \@retcases " . dump( @retcases ); 
-	say $tee "\@retstruct " . dump( @retstruct ); 
-	say $tee "\@notecases " . dump( @notecases ); 
+	#say $tee "INEXIT \@retcases " . dump( @retcases ); 
+	#say $tee "\@retstruct " . dump( @retstruct ); 
+	#say $tee "\@notecases " . dump( @notecases ); 
 	return ( \@retcases, \@retstruct, \@notecases );
 }	# END SUB RETRIEVE
 
@@ -968,17 +968,17 @@ sub report # This function retrieves the results of interest from the texts file
 				#say $tee "\$notecases[ \$countcase ][ \$countblock ][ \$countinstance ][ \$counttool ] } : " . dump( $notecases[ $countcase ][ $countblock ][ $countinstance ][ $counttool ] );
 				foreach $ret_ref ( @{ $notecases[ $countcase ][ $countblock ][ $countinstance ][ $counttool ] } )
 				{
-					say $tee "INREPORT \$ret_ref " . dump( $ret_ref );
-					%retitem = %$ret_ref; say $tee "dump---(\@retitem): " . dump(@retitem) . "\n\n";  
-					my $retfile = $retitem{retfile}; say $tee "dump---(\$retfile): " . dump($retfile) . "\n\n";  
-					my $reporttitle = $retitem{reporttitle}; say $tee "dump---(\$reporttitle): " . dump($reporttitle) . "\n\n";  
-					my $themereport = $retitem{themereport}; say $tee "dump---(\$themereport): " . dump($themereport) . "\n\n";  
-					my $semaphorego1 = $retitem{semaphorego1}; say $tee "dump---(\$semaphorego1): " . dump($semaphorego1) . "\n\n";  
-					my $semaphorego2 = $retitem{semaphorego2}; say $tee "dump---(\$semaphorego2): " . dump($semaphorego2) . "\n\n";  
-					my $semaphorestop1 = $retitem{semaphorestop1}; say $tee "dump---(\$semaphorestop1): " . dump($semaphorestop1) . "\n\n";
-					my $semaphorestop2 = $retitem{semaphorestop2}; say $tee "dump---(\$semaphorestop2): " . dump($semaphorestop2) . "\n\n";  
-					my $textpattern = $retitem{textpattern}; say $tee "dump---(\$textpattern): " . dump($textpattern) . "\n\n";  
-					my $afterlines = $retitem{afterlines}; say $tee "INREPORT dump---(\$afterlines): " . dump($afterlines) . "\n\n";  
+					#say $tee "INREPORT \$ret_ref " . dump( $ret_ref );
+					%retitem = %$ret_ref; #say $tee "dump---(\@retitem): " . dump(@retitem) . "\n\n";  
+					my $retfile = $retitem{retfile}; #say $tee "dump---(\$retfile): " . dump($retfile) . "\n\n";  
+					my $reporttitle = $retitem{reporttitle}; #say $tee "dump---(\$reporttitle): " . dump($reporttitle) . "\n\n";  
+					my $themereport = $retitem{themereport}; #say $tee "dump---(\$themereport): " . dump($themereport) . "\n\n";  
+					my $semaphorego1 = $retitem{semaphorego1}; #say $tee "dump---(\$semaphorego1): " . dump($semaphorego1) . "\n\n";  
+					my $semaphorego2 = $retitem{semaphorego2}; #say $tee "dump---(\$semaphorego2): " . dump($semaphorego2) . "\n\n";  
+					my $semaphorestop1 = $retitem{semaphorestop1}; #say $tee "dump---(\$semaphorestop1): " . dump($semaphorestop1) . "\n\n";
+					my $semaphorestop2 = $retitem{semaphorestop2}; #say $tee "dump---(\$semaphorestop2): " . dump($semaphorestop2) . "\n\n";  
+					my $textpattern = $retitem{textpattern}; #say $tee "dump---(\$textpattern): " . dump($textpattern) . "\n\n";  
+					my $afterlines = $retitem{afterlines}; #say $tee "INREPORT dump---(\$afterlines): " . dump($afterlines) . "\n\n";  
 					#my $adhoclines = $retitem{adhoclines}; #say $tee "dump---(\$adhoclines): " . dump($adhoclines) . "\n\n";
 					my ( $semaphore1, $semaphore2 );
 					
@@ -1022,7 +1022,7 @@ sub report # This function retrieves the results of interest from the texts file
 							
 							if ( not ( defined ( $afterlines ) ) )
 							{
-								say $tee "NOT DEFINED AFTERLINES FOR \$themereport $themereport";
+								#say $tee "NOT DEFINED AFTERLINES FOR \$themereport $themereport";
 								if ( ( $textpattern ne "" ) and ( $line =~ m/^$textpattern/ ) and ( $semaphore1 eq "on" ) and ( $semaphore2 eq "on" ) )
 								{
 									#print TOFILE "HIT REPORT1! "; #say TOFILE $line;
@@ -1033,13 +1033,12 @@ sub report # This function retrieves the results of interest from the texts file
 							}
 							else
 							{
-								say $tee "DEFINED AFTERLINES FOR \$themereport $themereport";
+								#say $tee "DEFINED AFTERLINES FOR \$themereport $themereport";
 								if ( ( $semaphore1 eq "on" ) and ( $semaphore2 eq "on" ) )
 								{
 									#print TOFILE "HIT REPORT1! "; #say TOFILE $line;
 									if ( not ( ref( $afterlines ) ) )
-									{
-										say $tee "NOT REF BUT DEFINED AFTERLINES FOR \$themereport $themereport";
+									{	#say $tee "NOT REF BUT DEFINED AFTERLINES FOR \$themereport $themereport";
 										if ( ( $afterlines ne "" ) and ( $countline == $afterlines ) )
 										{
 											#print TOFILE "HIT REPORT2! "; #say TOFILE $line;
@@ -1047,12 +1046,11 @@ sub report # This function retrieves the results of interest from the texts file
 										}
 									}
 									else
-									{
-										say $tee "REF AND DEFINED AFTERLINES FOR \$themereport $themereport";
-										my @lins = @$afterlines;  say $tee "\@lins @lins";
+									{	#say $tee "REF AND DEFINED AFTERLINES FOR \$themereport $themereport";
+										my @lins = @$afterlines;  #say $tee "\@lins @lins";
 										my $countlin = 0;
 										foreach my $lin ( @lins )
-										{	say $tee "FOREACH \$lin: $lin";
+										{	#say $tee "FOREACH \$lin: $lin";
 											my $countlocal = 0;
 											unless ( $lin =~ /-/ )
 											{
@@ -1145,9 +1143,7 @@ sub report # This function retrieves the results of interest from the texts file
 
 sub get_files # UNUSED. LEGACY. CUT.
 {
-	say "Extracting statistics for case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", instance: " . ( $countinstance + 1);
-	say TOFILE "
-	#Extracting statistics for case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", instance: " . ( $countinstance + 1);
+	say $tee "Extracting statistics for case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", instance: " . ( $countinstance + 1);
 	my ( $themereport, $countcase, $countblock, $counttheme, $countreport, $retfile, $repfile, 
 		$simtitle, $reporttitle, $simdatum, $retrievsref, $countinstance, $swap, $loadsortemps ) = @_;
 		
